@@ -12,11 +12,11 @@ use crate::{
 };
 use git2::{Reference, Repository};
 use ratatui::{
-    prelude::Rect,
+    layout::Size,
     text::{Line, Span},
 };
 
-pub(crate) fn create(config: Rc<Config>, repo: Rc<Repository>, size: Rect) -> Res<Screen> {
+pub(crate) fn create(config: Rc<Config>, repo: Rc<Repository>, size: Size) -> Res<Screen> {
     Screen::new(
         Rc::clone(&config),
         size,
