@@ -70,6 +70,20 @@ fn binary_file() {
     snapshot!(ctx, "jj<tab>");
 }
 
+#[test]
+fn collapsed_sections_config() {
+    let mut ctx = TestContext::setup_clone();
+    ctx.config().general.collapsed_sections = vec![
+        "untracked".into(),
+        "recent_commits".into(),
+        "branch_status".into(),
+        // TODO rebase / revert/ merge conlict?
+    ];
+    fs::write(ctx.dir.child("untracked_file.txt"), "").unwrap();
+
+    snapshot!(ctx, "");
+}
+
 #[test]
 fn log() {
     let ctx = TestContext::setup_clone();
